@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,14 +20,13 @@
  * 
  */
 
-#ifndef _SCORE
-#define _SCORE
+#ifndef XKOBO_H_SCORE
+#define XKOBO_H_SCORE
 
 #include "config.h"
 
 #define SCORE_SHOW_MAX      10
-#define SCORE_SAVE_MAX      30
-
+#define SCORE_SAVE_MAX      100
 
 class _scorefile{
     static int highscore;
@@ -36,9 +35,9 @@ class _scorefile{
   public:
     static void init(int *highscorep, int *stagep);
     static void record(int new_score, int stage);
-    static void show_high_scores();
+    static void show_high_scores(int to_stdout);
 };
 
 extern _scorefile scorefile;
 
-#endif // _SCORE
+#endif // XKOBO_H_SCORE
