@@ -1,7 +1,7 @@
 
 /*
  * XKOBO, a video-oriented game
- * Copyright (C) 1995  Akira Higuchi
+ * Copyright (C) 1995,1996  Akira Higuchi
  *     a-higuti@math.hokudai.ac.jp
  * 
  * This program is free software; you can redistribute it and/or modify it
@@ -20,12 +20,11 @@
  * 
  */
 
-#ifndef _XLCMAP
-#define _XLCMAP
+#ifndef XKOBO_H_XLCMAP
+#define XKOBO_H_XLCMAP
   
 #include "xlbacking.h"
 
-
 /*
  *
  *
@@ -36,17 +35,17 @@
 
 class win_cmap : public win_backing{
 
-    /************************ color map **************************/
-    
   protected:
+    int use_private_cmap;
     Colormap cmap;
+    unsigned long search_near(long r, long g, long b);
     
   public:
     win_cmap();
     ~win_cmap();
-    void make(win *back,int wx=0,int wy=0,int sizex=200,int sizey=200);
-    void cmset(XColor *col, int n=256);
+    void make(win *back,int wx, int wy, int sizex, int sizey, int use_private);
+    void cmset();
+    unsigned long alloc_color(long r, long g, long b);
 };
 
-#endif // _XLCMAP
-
+#endif // XKOBO_H_XLCMAP
